@@ -15,7 +15,7 @@ use Symbol      qw( qualify_to_ref  );
 # package variables
 ########################################################################
 
-our $VERSION    = '1.7';
+our $VERSION    = '1.00701';
 $VERSION = eval $VERSION;
 
 my $disp_list   = 'DISPATCH_OK';
@@ -55,7 +55,7 @@ sub import
     my $disp        = delete $argz{ dispatch    } || '';
     my $preproc     = delete $argz{ prefilter   } || '';
     my $postproc    = delete $argz{ postfilter  } || '';
-    my $inst_import = delete $argz{ import      } || 1;
+    my $inst_import = delete $argz{ import      } // 1;
 
     # if a dispatcher is being used then it must
     # be exported. in most cases this will be the
